Learn R Programming

GENLIB (version 1.0.2)

Classes of basic handling of genealogy data: Classes "GLmultiVector" "GLmultiArray4" "GLmultiMatrix" "GLmultiNumber"

Description

Objects created to carry information mostly between invisible functions.

Arguments

Rdversion

1.1

docType

class

Objects from the Class

Objects can be created by calls of the form new("GLmultiVector", 'matrix', depth = 'integer') new("GLmultiArray4", 'Array', depth = 'integer') new("GLmultiMatrix", 'Array', depth = 'integer') new("GLmultiNumber", 'numeric', depth = 'integer', .Names = 'character')

Extends

Class "matrix", from data part. Class "array", by class "matrix", distance 2. Class "structure", by class "matrix", distance 3. Class "vector", by class "matrix", distance 4, with explicit coerce.

Examples

Run this code
showClass("GLmultiVector")
showClass("GLmultiArray4")
showClass("GLmultiMatrix")
showClass("GLmultiNumber")

Run the code above in your browser using DataLab